==> haskell-lens-action-0.2.6-191-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lens-action.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lens-action
version:              0.2.6
visibility:           public
id:                   lens-action-0.2.6-Ggn9BTyAL43GzbLi2fcv1T
key:                  lens-action-0.2.6-Ggn9BTyAL43GzbLi2fcv1T
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2014 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/lens-action/
synopsis:             Monadic Getters and Folds
description:
    This package contains combinators and types for working with
    monadic getters and folds as split off from the original
    lens package.

category:             Data, Lenses, Generics
abi:                  c98443a7952c6c3725ae63db7a63b0a4
exposed:              True
exposed-modules:
    Control.Lens.Action Control.Lens.Action.Internal
    Control.Lens.Action.Reified Control.Lens.Action.Type

import-dirs:          /usr/lib/ghc-9.2.8/site-local/lens-action-0.2.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/lens-action-0.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lens-action
hs-libraries:         HSlens-action-0.2.6-Ggn9BTyAL43GzbLi2fcv1T
depends:
    base-4.16.4.0 comonad-5.0.8-7SvbYtos92D1jPcdvHdUhM
    contravariant-1.5.5-6oWUjmJNxDBFhugVD5s9dq
    lens-5.2.3-44yRBOAfB7iFMS16KrPjpp mtl-2.2.2
    profunctors-5.6.2-JxKh47DfsCg3BC80FZ7Vhy
    semigroupoids-5.3.7-CmdCtkiMB79IiDSsUdUQis transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-lens-action/html/lens-action.haddock
haddock-html:         /usr/share/doc/haskell-lens-action/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lens-action-0.2.6-193-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lens-action.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lens-action
version:              0.2.6
visibility:           public
id:                   lens-action-0.2.6-KpkMyRoJXYk8YSMGBO3QGA
key:                  lens-action-0.2.6-KpkMyRoJXYk8YSMGBO3QGA
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2014 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/lens-action/
synopsis:             Monadic Getters and Folds
description:
    This package contains combinators and types for working with
    monadic getters and folds as split off from the original
    lens package.

category:             Data, Lenses, Generics
abi:                  17f4e93ca5c0c8869b9deb7b929fad3f
exposed:              True
exposed-modules:
    Control.Lens.Action Control.Lens.Action.Internal
    Control.Lens.Action.Reified Control.Lens.Action.Type

import-dirs:          /usr/lib/ghc-9.2.8/site-local/lens-action-0.2.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/lens-action-0.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lens-action
hs-libraries:         HSlens-action-0.2.6-KpkMyRoJXYk8YSMGBO3QGA
depends:
    base-4.16.4.0 comonad-5.0.8-FPX8fqTXWBRIN28hv9cMY3
    contravariant-1.5.5-6oWUjmJNxDBFhugVD5s9dq
    lens-5.2.3-7KIPe29YDsM72AVahiJlyf mtl-2.2.2
    profunctors-5.6.2-2RGdXGkx1Cq1Oei2KZIiCf
    semigroupoids-5.3.7-DRrQ6HM3i3lBidmriDf0rx transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-lens-action/html/lens-action.haddock
haddock-html:         /usr/share/doc/haskell-lens-action/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
